#!/System/Executables/ruby -w
# Encoding: ISO-8859-1
# =========================================================================== #
# === Md5sum
#
# This small class will keep the md5sum.
#
# require 'md5sum'
# =========================================================================== #
begin
  require 'digest/md5'
rescue Exception => error
  puts error
end

require 'alias_e'

class Md5sum

  N = "\n"

  include AliasE

  # ========================================================================= #
  # === initialize
  # ========================================================================= #
  def initialize(
      input       = ARGV,
      run_already = true
    )
    case run_already
    when false, :dont_run_yet, :do_not_run_yet
      run_already = false
    end
    set_input(input)
    run if run_already
  end

  # ========================================================================= #
  # === set_input
  # ========================================================================= #
  def set_input(i = '')
    i = '' if i.nil?
    i = i.first if i.is_a? Array
    i = i.to_s.dup
    @input = i # Assign to input.
  end

  # ========================================================================= #
  # === show_result
  # ========================================================================= #
  def show_result
    e @result unless @input.nil? # must pass 1 arg
  end

  # ========================================================================= #
  # === reverse_md5
  #
  # This reverses a md5 hash, by using making use of the Digest module.
  #   reverse_md5 '5f4dcc3b5aa765d61d8327deb882cf99'
  # ========================================================================= #
  def reverse_md5(md5hash = '5f4dcc3b5aa765d61d8327deb882cf99')
    require 'digest/md5reverse'
    reverse_hexdigest = Digest::MD5Reverse.to_reverse_hexdigest(md5hash.to_s)
    e N+"\tmd5hash word [#{reverse_hexdigest}] "+N # md5hash word [password]
  end

  # ========================================================================= #
  # === Md5sum.reverse_md5
  #
  # Usage examples:
  #   require 'md5sum'; Md5sum.reverse_md5("/Depot/jjj/lalalala.flv")
  # ========================================================================= #
  def self.reverse_md5(i)
    Md5sum.new(nil,false).reverse_md5(i)
  end

  # ========================================================================= #
  # === set_result
  # ========================================================================= #
  def set_result
    @result = return_md5sum(@input)
  end

  # ========================================================================= #
  # === Md5sum[]
  # ========================================================================= #
  def self.[](i)
    Md5sum.new(i)
  end

  # ========================================================================= #
  # === file?
  # ========================================================================= #
  def file?
    @input
  end

  # ========================================================================= #
  # === return_md5sum
  #
  # Example results:
  #   1897a33110ebfee800fb9562711cac02
  # ========================================================================= #  
  def return_md5sum(input = @input)
    if input.is_a? Array
      input.each { |file|
        if File.file? file
          dataset = File.read(file)
        else
          dataset = file
        end
        digest = Digest::MD5.hexdigest(dataset)
        return digest
      }
    else
      if File.file? input
        dataset = File.read(input)
      else
        dataset = input
      end
      return Digest::MD5.hexdigest(dataset)
    end
  end; alias md5sum? return_md5sum # === md5sum?

  # ========================================================================= #
  # === run                                                         (run tag)
  #
  # Will return the md5sum.
  # ========================================================================= #
  def run(shall_we_show_the_result = false)
    case shall_we_show_the_result
    when :do_show_the_result
      shall_we_show_the_result = true
    end
    set_result
    show_result if shall_we_show_the_result
  end

end

if __FILE__ == $PROGRAM_NAME
  _ = Md5sum.new(ARGV, :do_not_run_yet)
  unless File.exist?(_.file?)
    _.reverse_md5 '61c12f4e84dc393aaa4849db9b78aa84'
  end
  _.run :do_show_the_result
end
# rubymd5sum RamonDekkersHightlight.avi
# rubymd5sum